Index: apps/app_forkcdr.c
===================================================================
--- apps/app_forkcdr.c	(revision 225404)
+++ apps/app_forkcdr.c	(working copy)
@@ -184,7 +184,7 @@
 	while (cdr->next)
 		cdr = cdr->next;
 	
-	if (!(newcdr = ast_cdr_dup(cdr)))
+	if (!(newcdr = ast_cdr_dup_unique(cdr)))
 		return;
 	
 	ast_cdr_append(cdr, newcdr);
Index: funcs/func_cdr.c
===================================================================
--- funcs/func_cdr.c	(revision 225404)
+++ funcs/func_cdr.c	(working copy)
@@ -99,6 +99,9 @@
 					<enum name="channel">
 						<para>Channel name.</para>
 					</enum>
+					<enum name="sequence">
+						<para>CDR sequence number.</param>
+					</enum>
 				</enumlist>
 			</parameter>
 			<parameter name="options" required="false">
Index: include/asterisk/cdr.h
===================================================================
--- include/asterisk/cdr.h	(revision 225404)
+++ include/asterisk/cdr.h	(working copy)
@@ -110,6 +110,8 @@
 	char linkedid[32];
 	/*! User field */
 	char userfield[AST_MAX_USER_FIELD];
+	/*! Sequence field */
+	int sequence;
 
 	/*! A linked list for variables */
 	struct varshead varshead;
@@ -143,9 +145,20 @@
 struct ast_cdr *ast_cdr_alloc(void);
 
 /*! 
+ * \brief Duplicate a record and increment the sequence number.
+ * \param cdr the record to duplicate
+ * \retval a malloc'd ast_cdr structure, 
+ * \retval NULL on error (malloc failure)
+ * \see ast_cdr_dup()
+ */
+struct ast_cdr *ast_cdr_dup_unique(struct ast_cdr *cdr);
+
+/*! 
  * \brief Duplicate a record 
+ * \param cdr the record to duplicate
  * \retval a malloc'd ast_cdr structure, 
  * \retval NULL on error (malloc failure)
+ * \see ast_cdr_dup_unique()
  */
 struct ast_cdr *ast_cdr_dup(struct ast_cdr *cdr);
 
Index: main/cdr.c
===================================================================
--- main/cdr.c	(revision 225404)
+++ main/cdr.c	(working copy)
@@ -74,6 +74,11 @@
 	struct ast_cdr_batch_item *tail;
 } *batch = NULL;
 
+
+static int cdr_sequence =  0;
+
+static int cdr_seq_inc(struct ast_cdr *cdr);
+
 static struct sched_context *sched;
 static int cdr_sched = -1;
 static pthread_t cdr_thread = AST_PTHREADT_NULL;
@@ -165,6 +170,16 @@
 	return unanswered;
 }
 
+struct ast_cdr *ast_cdr_dup_unique(struct ast_cdr *cdr) 
+{
+	struct ast_cdr *newcdr = ast_cdr_dup(cdr);
+	if (!newcdr)
+		return NULL;
+
+	cdr_seq_inc(newcdr);
+	return newcdr;
+}
+
 /*! Duplicate a CDR record 
 	\returns Pointer to new CDR record
 */
@@ -279,6 +294,8 @@
 		ast_copy_string(workspace, cdr->linkedid, workspacelen);
 	else if (!strcasecmp(name, "userfield"))
 		ast_copy_string(workspace, cdr->userfield, workspacelen);
+	else if (!strcasecmp(name, "sequence"))
+		snprintf(workspace, workspacelen, "%d", cdr->sequence);
 	else if ((varbuf = ast_cdr_getvar_internal(cdr, name, recur)))
 		ast_copy_string(workspace, varbuf, workspacelen);
 	else
@@ -292,7 +309,7 @@
 static const char * const cdr_readonly_vars[] = { "clid", "src", "dst", "dcontext", "channel", "dstchannel",
 						  "lastapp", "lastdata", "start", "answer", "end", "duration",
 						  "billsec", "disposition", "amaflags", "accountcode", "uniqueid", "linkedid",
-						  "userfield", NULL };
+						  "userfield", "sequence", NULL };
 /*! Set a CDR channel variable 
 	\note You can't set the CDR variables that belong to the actual CDR record, like "billsec".
 */
@@ -847,6 +864,11 @@
 	return 0;
 }
 
+static int cdr_seq_inc(struct ast_cdr *cdr)
+{
+	return (cdr->sequence = ast_atomic_fetchadd_int(&cdr_sequence, +1));
+}
+
 int ast_cdr_init(struct ast_cdr *cdr, struct ast_channel *c)
 {
 	char *chan;
@@ -856,6 +878,7 @@
 			chan = S_OR(cdr->channel, "<unknown>");
 			ast_copy_string(cdr->channel, c->name, sizeof(cdr->channel));
 			set_one_cid(cdr, c);
+			cdr_seq_inc(cdr);
 
 			cdr->disposition = (c->_state == AST_STATE_UP) ?  AST_CDR_ANSWERED : AST_CDR_NOANSWER;
 			cdr->amaflags = c->amaflags ? c->amaflags :  ast_default_amaflags;
Index: main/features.c
===================================================================
--- main/features.c	(revision 225404)
+++ main/features.c	(working copy)
@@ -2804,7 +2804,7 @@
 		if (chan_cdr) {
 			ast_set_flag(chan_cdr, AST_CDR_FLAG_MAIN);
 			ast_cdr_update(chan);
-			bridge_cdr = ast_cdr_dup(chan_cdr);
+			bridge_cdr = ast_cdr_dup_unique(chan_cdr);
 			ast_copy_string(bridge_cdr->lastapp, S_OR(chan->appl, ""), sizeof(bridge_cdr->lastapp));
 			ast_copy_string(bridge_cdr->lastdata, S_OR(chan->data, ""), sizeof(bridge_cdr->lastdata));
 		} else {
Index: configs/cdr_custom.conf.sample
===================================================================
--- configs/cdr_custom.conf.sample	(revision 225404)
+++ configs/cdr_custom.conf.sample	(working copy)
@@ -7,6 +7,6 @@
 ; Master.csv, Simple.csv, or both.
 ;
 ;[mappings]
-;Master.csv => ${CSV_QUOTE(${CDR(clid)})},${CSV_QUOTE(${CDR(src)})},${CSV_QUOTE(${CDR(dst)})},${CSV_QUOTE(${CDR(dcontext)})},${CSV_QUOTE(${CDR(channel)})},${CSV_QUOTE(${CDR(dstchannel)})},${CSV_QUOTE(${CDR(lastapp)})},${CSV_QUOTE(${CDR(lastdata)})},${CSV_QUOTE(${CDR(start)})},${CSV_QUOTE(${CDR(answer)})},${CSV_QUOTE(${CDR(end)})},${CSV_QUOTE(${CDR(duration)})},${CSV_QUOTE(${CDR(billsec)})},${CSV_QUOTE(${CDR(disposition)})},${CSV_QUOTE(${CDR(amaflags)})},${CSV_QUOTE(${CDR(accountcode)})},${CSV_QUOTE(${CDR(uniqueid)})},${CSV_QUOTE(${CDR(userfield)})}
+;Master.csv => ${CSV_QUOTE(${CDR(clid)})},${CSV_QUOTE(${CDR(src)})},${CSV_QUOTE(${CDR(dst)})},${CSV_QUOTE(${CDR(dcontext)})},${CSV_QUOTE(${CDR(channel)})},${CSV_QUOTE(${CDR(dstchannel)})},${CSV_QUOTE(${CDR(lastapp)})},${CSV_QUOTE(${CDR(lastdata)})},${CSV_QUOTE(${CDR(start)})},${CSV_QUOTE(${CDR(answer)})},${CSV_QUOTE(${CDR(end)})},${CSV_QUOTE(${CDR(duration)})},${CSV_QUOTE(${CDR(billsec)})},${CSV_QUOTE(${CDR(disposition)})},${CSV_QUOTE(${CDR(amaflags)})},${CSV_QUOTE(${CDR(accountcode)})},${CSV_QUOTE(${CDR(uniqueid)})},${CSV_QUOTE(${CDR(userfield)})},${CDR(sequence)}
 ;Simple.csv => ${CSV_QUOTE(${EPOCH})},${CSV_QUOTE(${CDR(src)})},${CSV_QUOTE(${CDR(dst)})}
 
